#!/bin/bash/python3
import time
import collections
import dns
import dns.resolver
import dns.zone
import socket


class DBCName(object):
    desflow_request = None
    comments = None

    def __init__(self, logger=None, log_message=None):
        self.logger = logger
        self.log_message = log_message

    def get_pointing_cnames(self, hostname):
        """
            Method to Get pointing cnames
            :parameter hostname
        """
        hostname = hostname.lower().replace('.win.ia55.net', '') + '.win.ia55.net'
        cnames_to_target, target_to_cnames = self.get_all_cnames_as_dict()
        return cnames_to_target.get(hostname.lower(), list())

    def get_all_cnames_as_dict(self):
        retry_count = 0
        retry_count_limit = 15
        while retry_count < retry_count_limit:
            try:
                IN = dns.rdataclass.from_text('IN')
                CNAME = dns.rdatatype.from_text('CNAME')
                core_elb_ip_addr = socket.gethostbyname('core.i.ia55.net')
                xfr = dns.query.xfr(core_elb_ip_addr, 'ia55.net', relativize=False)
                zone = dns.zone.from_xfr(xfr, relativize=False)
                names_to_cnames = collections.OrderedDict()
                cnames_to_names = collections.OrderedDict()

                for name in sorted(zone.nodes.keys(), key=lambda x: x.to_text().lower()):
                    try:
                        canon_name = name.to_text().lower()[0:-1]
                        for cname in zone[name].find_rdataset(IN, CNAME):
                            canon_cname = cname.to_text().lower()[0:-1]
                            cnames_to_names.setdefault(canon_cname, []).append(canon_name)
                            names_to_cnames.setdefault(canon_name, []).append(canon_cname)
                    except:
                        pass

                return cnames_to_names, names_to_cnames
            except Exception as ex:
                self.log_message(
                    "Error while fetching cname from core.i.ia55.net {}, trying again {}".format(str(ex), retry_count))
                time.sleep(5)
            retry_count += 1
        return {}, {}


dbc = DBCName()
print("Find the CName for: dbmonitor5b.win.ia55.net" )
cname = dbc.get_pointing_cnames('dbmonitor5b.win.ia55.net')
print("CName is", cname)



from setuptools import setup

setup(name='hello_word',
      version='0.1.3',
      description='Hello Word Project',
      url='https://gitlab.com/arcesium/private/users/guptmani/hello_word',
      author='guptmani',
      author_email='guptmani@arcesium.com',
      license='MIT',
      packages=['hello_word'],
      install_requires=[
          'dnspython',
	      'sockets',
      ],
      zip_safe=False)



import pyodbc

class Connection(object):
    """Class to connect to any database server
    :parameter server name & database name (optional)"""
    
    
    """
    def __del__(self):
        
        if self.conn:
            self.conn.commit()
            self.conn.close()
    """
    # Method to connect to the server
    def connect(self, server_name, timeout=5):

        server_name = server_name.lower().replace('.win.ia55.net', '') + '.win.ia55.net'
        retry_count = 0
        SQL_CONN_RETRY_COUNT = 1 
        while retry_count < SQL_CONN_RETRY_COUNT:
            # try:
            connectionstring = 'DRIVER={Easysoft ODBC-SQL Server};Server='+server_name+';UID=;PWD=;ServerSPN=MSSQLSvc/'+server_name+';APP=dbcnames;'
            conn = pyodbc.connect(connectionstring, timeout=timeout)
            conn.autocommit = True
            self.conn = conn
            return conn
            # except Exception as ex:
            #     print("Error while creating database connection to {} server {}, trying again {}".format(server_name, str(ex), retry_count))
            retry_count += 1

        return None



# conn = Connection()
# cn = conn.connect('dbmonitor5b.win.ia55.net')
# cnxn = pyodbc.connect('DRIVER={Easysoft ODBC-SQL Server};Server=DBGELBASEDEVNYC;UID=;PWD=;APP=test;ServerSPN=MSSQLSvc/reins')
# cursor = cnxn.cursor()
# print(cursor.execute('select @@servername').fetchall())

connection_string = 'DRIVER={ODBC Driver 17 for SQL Server};Server=dbmonitor5b.win.ia55.net;database=master;Trusted_Connection=yes;'
con = pyodbc.connect(connection_string)
cursor = cnxn.cursor()
print(cursor.execute('select @@servername').fetchall())

# cur = cn.cursor()
# cur.execute("select @@servername")  # Execute the query
# records = cur.fetchall()
# print(records)


